Index: src/compiler/code-stub-assembler.h |
diff --git a/src/compiler/code-stub-assembler.h b/src/compiler/code-stub-assembler.h |
index 8a6f6ae226bd69a15d522cedf90f88e38ecaeece..7f11d56efd35b3fd9b925c66db437c7e98f22484 100644 |
--- a/src/compiler/code-stub-assembler.h |
+++ b/src/compiler/code-stub-assembler.h |
@@ -310,10 +310,21 @@ class CodeStubAssembler { |
Node* TruncateHeapNumberValueToWord32(Node* object); |
// Load the bit field of a Map. |
Node* LoadMapBitField(Node* map); |
- // Load the instance type of a Map. |
+ // Load bit field 2 of a map. |
+ Node* LoadMapBitField2(Node* map); |
+ // Load bit field 3 of a map. |
+ Node* LoadMapBitField3(Node* map); |
+ // Load the instance type of a map. |
Node* LoadMapInstanceType(Node* map); |
+ // Load the instance descriptors of a map. |
+ Node* LoadMapDescriptors(Node* map); |
+ |
+ // Load the hash field of a name. |
+ Node* LoadNameHash(Node* name); |
// Load an array element from a FixedArray. |
+ Node* LoadFixedArrayElementInt32Index(Node* object, Node* int32_index, |
+ int additional_offset = 0); |
Node* LoadFixedArrayElementSmiIndex(Node* object, Node* smi_index, |
int additional_offset = 0); |
Node* LoadFixedArrayElementConstantIndex(Node* object, int index); |
@@ -335,6 +346,11 @@ class CodeStubAssembler { |
// Load the instance type of an HeapObject. |
Node* LoadInstanceType(Node* object); |
+ // Load the elements backing store of a JSObject. |
+ Node* LoadElements(Node* object); |
+ // Load the length of a fixed array base instance. |
+ Node* LoadFixedArrayBaseLength(Node* array); |
+ |
// Returns a node that is true if the given bit is set in |word32|. |
template <typename T> |
Node* BitFieldDecode(Node* word32) { |